@@ -20,7 +20,6 @@
 
 #include "backend/corebackend.h"
 #include "backend/corebackendmanager.h"
-#include "backend/corebackenddevice.h"
 
 #include "core/copytarget.h"
 #include "core/copytargetdevice.h"
@@ -40,18 +39,12 @@ CopySourceDevice::CopySourceDevice(Device& d, qint64 firstbyte, qint64 lastbyte)
 {
 }
 
-/** Destructs a CopySourceDevice */
-CopySourceDevice::~CopySourceDevice()
-{
-    delete m_BackendDevice;
-}
-
 /** Opens the Device
     @return true if the Device could be successfully opened
 */
 bool CopySourceDevice::open()
 {
-    m_BackendDevice = CoreBackendManager::self()->backend()->openDeviceExclusive(device().deviceNode());
+    m_BackendDevice = CoreBackendManager::self()->backend()->openDeviceExclusive(device());
     return m_BackendDevice != nullptr;
 }
 
@@ -63,22 +56,6 @@ qint64 CopySourceDevice::length() const
     return lastByte() - firstByte() + 1;
 }
 
-/** Reads a given number of bytes from the Device into the given buffer.
-
-    Note that @p readOffset must be greater or equal than zero.
-
-    @param buffer the buffer to store the read bytes in
-    @param readOffset the offset to begin reading
-    @param size the number of bytes to read
-
-    @return true if successful
-*/
-bool CopySourceDevice::readData(QByteArray& buffer, qint64 readOffset, qint64 size)
-{
-    Q_ASSERT(readOffset >= 0);
-    return m_BackendDevice->readData(buffer, readOffset, size);
-}
-
 /** Checks if this CopySourceDevice overlaps with the given CopyTarget
     @param target the CopyTarget to check overlapping with
     @return true if overlaps
@@ -103,3 +80,8 @@ bool CopySourceDevice::overlaps(const CopyTarget& target) const
 
     return false;
 }
+
+QString CopySourceDevice::path() const
+{
+    return m_Device.deviceNode();
+}
