@@ -19,11 +19,9 @@
 
 #include "backend/corebackend.h"
 #include "backend/corebackendmanager.h"
-#include "backend/corebackenddevice.h"
 
 #include "core/device.h"
 
-
 /** Constructs a device to copy to.
     @param d the Device to copy to
     @param firstbyte the first byte on the Device to write to
@@ -38,36 +36,16 @@ CopyTargetDevice::CopyTargetDevice(Device& d, qint64 firstbyte, qint64 lastbyte)
 {
 }
 
-/** Destructs a CopyTargetDevice */
-CopyTargetDevice::~CopyTargetDevice()
-{
-    delete m_BackendDevice;
-}
-
 /** Opens a CopyTargetDevice for writing to.
     @return true on success
 */
 bool CopyTargetDevice::open()
 {
-    m_BackendDevice = CoreBackendManager::self()->backend()->openDeviceExclusive(device().deviceNode());
+    m_BackendDevice = CoreBackendManager::self()->backend()->openDeviceExclusive(device());
     return m_BackendDevice != nullptr;
 }
 
-/** Writes the given number of bytes to the Device.
-
-    Note that @p writeOffset must be greater or equal than zero.
-
-    @param buffer the data to write
-    @param writeOffset where to start writing on the Device
-    @return true on success
-*/
-bool CopyTargetDevice::writeData(QByteArray& buffer, qint64 writeOffset)
+QString CopyTargetDevice::path() const
 {
-    Q_ASSERT(writeOffset >= 0);
-    bool rval = m_BackendDevice->writeData(buffer, writeOffset);
-
-    if (rval)
-        setBytesWritten(bytesWritten() + buffer.size());
-
-    return rval;
+    return m_Device.deviceNode();
 }
