@@ -40,7 +40,6 @@ public:
 
 public:
     bool open() override;
-    bool writeData(QByteArray& buffer, qint64 writeOffset) override;
 
     qint64 firstByte() const override {
         return 0;    /**< @return always 0 for a file */
@@ -49,6 +48,10 @@ public:
         return bytesWritten();    /**< @return the number of bytes written so far */
     }
 
+    QString path() const override {
+        return m_File.fileName();
+    }
+
 protected:
     QFile& file() {
         return m_File;
