@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
+ *  Copyright (C) 2018 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -15,13 +16,14 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(KPMCORE_DISKDEVICE_H)
-
+#ifndef KPMCORE_DISKDEVICE_H
 #define KPMCORE_DISKDEVICE_H
 
 #include "util/libpartitionmanagerexport.h"
 #include "core/device.h"
 
+#include <memory>
+
 #include <QString>
 #include <QObject>
 #include <QtGlobal>
@@ -30,6 +32,7 @@ class PartitionTable;
 class CreatePartitionTableOperation;
 class CoreBackend;
 class SmartStatus;
+class DiskDevicePrivate;
 
 /** A disk device.
 
@@ -40,6 +43,7 @@ class SmartStatus;
     @see PartitionTable, Partition
     @author Volker Lanz <vl@fidra.de>
 */
+
 class LIBKPMCORE_EXPORT DiskDevice : public Device
 {
     Q_DISABLE_COPY(DiskDevice)
@@ -51,34 +55,42 @@ public:
     DiskDevice(const QString& name, const QString& deviceNode, qint32 heads, qint32 numSectors, qint32 cylinders, qint64 sectorSize, const QString& iconName = QString());
 
 public:
-    qint32 heads() const {
-        return m_Heads;    /**< @return the number of heads on the Device in CHS notation */
-    }
-    qint32 cylinders() const {
-        return m_Cylinders;    /**< @return the number of cylinders on the Device in CHS notation */
-    }
-    qint32 sectorsPerTrack() const {
-        return m_SectorsPerTrack;    /**< @return the number of sectors on the Device in CHS notation */
-    }
-    qint64 physicalSectorSize() const {
-        return m_PhysicalSectorSize;    /**< @return the physical sector size the Device uses or -1 if unknown */
-    }
-    qint64 logicalSectorSize() const {
-        return m_LogicalSectorSize;    /**< @return the logical sector size the Device uses */
-    }
-    qint64 totalSectors() const {
-        return static_cast<qint64>(heads()) * cylinders() * sectorsPerTrack();    /**< @return the total number of sectors on the device */
-    }
-    qint64 cylinderSize() const {
-        return static_cast<qint64>(heads()) * sectorsPerTrack();    /**< @return the size of a cylinder on this Device in sectors */
-    }
+    /**
+     * @return the number of heads on the Device in CHS notation
+     */
+    [[deprecated]]
+    qint32 heads() const;
 
-private:
-    qint32 m_Heads;
-    qint32 m_SectorsPerTrack;
-    qint32 m_Cylinders;
-    qint64 m_LogicalSectorSize;
-    qint64 m_PhysicalSectorSize;
+    /**
+     * @return the number of cylinders on the Device in CHS notation
+     */
+    [[deprecated]]
+    qint32 cylinders() const;
+
+    /**
+     * @return the number of sectors on the Device in CHS notation
+     */
+    qint32 sectorsPerTrack() const;
+
+    /**
+     * @return the physical sector size the Device uses or -1 if unknown
+     */
+    qint64 physicalSectorSize() const;
+
+    /**
+     * @return the logical sector size the Device uses
+     */
+    qint64 logicalSectorSize() const;
+
+    /**
+     * @return the total number of sectors on the device
+     */
+    qint64 totalSectors() const;
+
+    /**
+     * @return the size of a cylinder on this Device in sectors
+     */
+    qint64 cylinderSize() const;
 };
 
 #endif
