@@ -25,9 +25,6 @@
 #include <QDBusReply>
 #include <QMutex>
 
-#include <pwd.h>
-#include <unistd.h>
-
 /** Constructs an OperationRunner.
     @param ostack the OperationStack to act on
 */
@@ -50,15 +47,6 @@ void OperationRunner::run()
     bool status = true;
 
     // Disable Plasma removable device automounting
-    unsigned int currentUid = getuid(); // 0 if running as root
-    char *login = getlogin();
-    if (login != nullptr){
-        passwd* pwnam = getpwnam(login);
-        if (pwnam != nullptr) {
-            unsigned int userId = pwnam->pw_uid; // uid of original user before sudo
-            seteuid(userId);
-        }
-    }
     QStringList modules;
     QDBusConnection bus = QDBusConnection::connectToBus(QDBusConnection::SessionBus, QStringLiteral("sessionBus"));
     QDBusInterface kdedInterface( QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded5"), bus );
@@ -69,13 +57,12 @@ void OperationRunner::run()
     bool automounter = modules.contains(automounterService);
     if (automounter)
         kdedInterface.call( QStringLiteral("unloadModule"), automounterService );
-    seteuid(currentUid);
 
     for (int i = 0; i < numOperations(); i++) {
         suspendMutex().lock();
+        suspendMutex().unlock();
 
         if (!status || isCancelling()) {
-            suspendMutex().unlock();
             break;
         }
 
@@ -92,13 +79,6 @@ void OperationRunner::run()
         disconnect(op, &Operation::progress, this, &OperationRunner::progressSub);
 
         emit opFinished(i + 1, op);
-
-        suspendMutex().unlock();
-
-        // Sleep a little to give others a chance to suspend us. This should normally not be
-        // required -- is it possible that the compiler just optimizes our unlock/lock away
-        // if we don't sleep?
-        msleep(5);
     }
 
     if (automounter)
