@@ -18,78 +18,78 @@
 
 #include "core/smartattribute.h"
 #include "core/smartstatus.h"
+#include "core/smartattributeparseddata.h"
 
 #include <QLocale>
 
 #include <KLocalizedString>
 #include <KFormat>
 
-#include <atasmart.h>
-
 static QString getAttrName(qint32 id);
 static QString getAttrDescription(qint32 id);
-static QString getPrettyValue(quint64 value, qint64 unit);
-static SmartAttribute::Assessment getAssessment(const SkSmartAttributeParsedData* a);
-static QString getRaw(const uint8_t*);
+static QString getPrettyValue(quint64 value, SmartAttributeUnit unit);
+static SmartAttribute::Assessment getAssessment(const SmartAttributeParsedData& a);
+static QString getRaw(quint64 raw);
 
-SmartAttribute::SmartAttribute(const SkSmartAttributeParsedData* a) :
-    m_Id(a->id),
-    m_Name(getAttrName(a->id)),
-    m_Desc(getAttrDescription(a->id)),
-    m_FailureType(a->prefailure ? PreFailure : OldAge),
-    m_UpdateType(a->online ? Online : Offline),
-    m_Current(a->current_value_valid ?  a->current_value : -1),
-    m_Worst(a->worst_value_valid ? a->worst_value : -1),
-    m_Threshold(a->threshold_valid ? a->threshold : -1),
-    m_Raw(getRaw(a->raw)),
+SmartAttribute::SmartAttribute(const SmartAttributeParsedData& a) :
+    m_Id(a.id()),
+    m_Name(getAttrName(a.id())),
+    m_Desc(getAttrDescription(a.id())),
+    m_FailureType(a.prefailure() ? FailureType::PreFailure : FailureType::OldAge),
+    m_UpdateType(a.online() ? UpdateType::Online : UpdateType::Offline),
+    m_Current(a.currentValueValid() ?  a.currentValue() : -1),
+    m_Worst(a.worstValueValid() ? a.worstValue() : -1),
+    m_Threshold(a.thresholdValid() ? a.threshold() : -1),
+    m_Raw(getRaw(a.raw())),
     m_Assessment(getAssessment(a)),
-    m_Value(getPrettyValue(a->pretty_value, a->pretty_unit))
+    m_Value(getPrettyValue(a.prettyValue(), a.prettyUnit()))
 {
+    
 }
 
 QString SmartAttribute::assessmentToString(Assessment a)
 {
     switch (a) {
-    case Failing:
+    case Assessment::Failing:
         return xi18nc("@item:intable", "failing");
 
-    case HasFailed:
+    case Assessment::HasFailed:
         return xi18nc("@item:intable", "has failed");
 
-    case Warning:
+    case Assessment::Warning:
         return xi18nc("@item:intable", "warning");
 
-    case Good:
+    case Assessment::Good:
         return xi18nc("@item:intable", "good");
 
-    case NotApplicable:
+    case Assessment::NotApplicable:
     default:
         return xi18nc("@item:intable not applicable", "N/A");
     }
 }
 
-static QString getPrettyValue(quint64 value, qint64 unit)
+static QString getPrettyValue(quint64 value, SmartAttributeUnit unit)
 {
     QString rval;
 
     switch (unit) {
-    case SK_SMART_ATTRIBUTE_UNIT_MSECONDS:
+    case SmartAttributeUnit::Miliseconds:
         rval = KFormat().formatDuration(value);
         break;
 
-    case SK_SMART_ATTRIBUTE_UNIT_SECTORS:
+    case SmartAttributeUnit::Sectors:
         rval = xi18ncp("@item:intable", "%1 sector", "%1 sectors", value);
         break;
 
-    case SK_SMART_ATTRIBUTE_UNIT_MKELVIN:
+    case SmartAttributeUnit::Milikelvin:
         rval = SmartStatus::tempToString(value);
         break;
 
-    case SK_SMART_ATTRIBUTE_UNIT_NONE:
+    case SmartAttributeUnit::None:
         rval = QLocale().toString(value);
         break;
 
-    case SK_SMART_ATTRIBUTE_UNIT_UNKNOWN:
+    case SmartAttributeUnit::Unknown:
     default:
         rval = xi18nc("@item:intable not applicable", "N/A");
         break;
@@ -128,6 +128,7 @@ static const AttrDetails* attrDetails()
         { 175,  i18nc("SMART attr name", "SSD Power Loss Protection Failure"), i18nc("SMART attr description", "Last test result, saturated at its maximum value. Bytes 0-1: last test result as microseconds to discharge cap in range [25, 5000000], lower indicates specific error code. Bytes 2-3: minutes since last test. Bytes 4-5: lifetime number of tests. Normalized value is set to 1 on test failure or 11 if the capacitor has been tested in an excessive temperature condition, otherwise 100.") },
         { 176,  i18nc("SMART attr name", "SSD Erase Fail Count (chip)"), i18nc("SMART attr description", "Number of flash erase command failures.") },
         { 177,  i18nc("SMART attr name", "SSD Wear Range Delta"), i18nc("SMART attr description", "Delta between most-worn and least-worn flash blocks.") },
+        { 178,  i18nc("SMART attr name", "SSD Used Reserved Block Count Total"), i18nc("SMART attr description", "\"Pre-Fail\" Samsung attribute.") },
         { 179,  i18nc("SMART attr name", "SSD Used Reserved Block Count Total"), i18nc("SMART attr description", "\"Pre-Fail\" Samsung attribute.") },
         { 180,  i18nc("SMART attr name", "SSD Unused Reserved Block Count Total"), i18nc("SMART attr description", "\"Pre-Fail\" HP attribute.") },
         { 181,  i18nc("SMART attr name", "SSD Program Fail Count Total or Non-4K Aligned Access Count"), i18nc("SMART attr description", "Number of flash program operation failures since the drive was deployed.") },
@@ -214,43 +215,41 @@ static QString getAttrDescription(qint32 id)
     return QString();
 }
 
-static SmartAttribute::Assessment getAssessment(const SkSmartAttributeParsedData* a)
+static SmartAttribute::Assessment getAssessment(const SmartAttributeParsedData& a)
 {
-    SmartAttribute::Assessment rval = SmartAttribute::NotApplicable;
+    SmartAttribute::Assessment rval = SmartAttribute::Assessment::NotApplicable;
 
     bool failed = false;
     bool hasFailed = false;
 
-    if (a->prefailure) {
-        if (a->good_now_valid && !a->good_now)
+    if (a.prefailure()) {
+        if (a.goodNowValid() && !a.goodNow())
             failed = true;
 
-        if (a->good_in_the_past_valid && !a->good_in_the_past)
+        if (a.goodInThePastValid() && !a.goodInThePast())
             hasFailed = true;
-    } else if (a->threshold_valid) {
-        if (a->current_value_valid && a->current_value <= a->threshold)
+    } else if (a.thresholdValid()) {
+        if (a.currentValueValid() && a.currentValue() <= a.threshold())
             failed = true;
-        else if (a->worst_value_valid && a->worst_value <= a->threshold)
+        else if (a.worstValueValid() && a.worstValue() <= a.threshold())
             hasFailed = true;
     }
 
     if (failed)
-        rval = SmartAttribute::Failing;
+        rval = SmartAttribute::Assessment::Failing;
     else if (hasFailed)
-        rval = SmartAttribute::HasFailed;
-    else if (a->warn)
-        rval = SmartAttribute::Warning;
-    else if (a->good_now_valid)
-        rval = SmartAttribute::Good;
+        rval = SmartAttribute::Assessment::HasFailed;
+    else if (a.warn())
+        rval = SmartAttribute::Assessment::Warning;
+    else if (a.goodNowValid())
+        rval = SmartAttribute::Assessment::Good;
 
     return rval;
 }
 
-static QString getRaw(const uint8_t* raw)
+static QString getRaw(quint64 raw)
 {
     QString rval = QStringLiteral("0x");
-    for (qint32 i = 5; i >= 0; i--)
-        rval += QStringLiteral("%1").arg(raw[i], 2, 16, QLatin1Char('0'));
-
+    rval += QStringLiteral("%1").arg(raw, 12, 16, QLatin1Char('0'));
     return rval;
 }
