@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(BTRFS__H)
+#if !defined(KPMCORE_BTRFS_H)
 
-#define BTRFS__H
+#define KPMCORE_BTRFS_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -38,7 +38,7 @@ namespace FS
 class LIBKPMCORE_EXPORT btrfs : public FileSystem
 {
 public:
-    btrfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    btrfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
@@ -61,6 +61,9 @@ public:
     CommandSupportType supportCreate() const override {
         return m_Create;
     }
+    CommandSupportType supportCreateWithFeatures() const override {
+        return m_Create;
+    }
     CommandSupportType supportGrow() const override {
         return m_Grow;
     }
@@ -100,7 +103,7 @@ public:
 
     qint64 minCapacity() const override;
     qint64 maxCapacity() const override;
-    qint64 maxLabelLength() const override;
+    int maxLabelLength() const override;
     SupportTool supportToolName() const override;
     bool supportToolFound() const override;
 
