@@ -31,13 +31,8 @@
 
 namespace FS
 {
-fat16::fat16(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label) :
-    fat12(firstsector, lastsector, sectorsused, label, FileSystem::Type::Fat16)
-{
-}
-
-fat16::fat16(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, FileSystem::Type type) :
-    fat12(firstsector, lastsector, sectorsused, label, type)
+fat16::fat16(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features, FileSystem::Type type) :
+    fat12(firstsector, lastsector, sectorsused, label, features, type)
 {
 }
 
@@ -53,6 +48,11 @@ void fat16::init()
     m_Grow = findExternal(QStringLiteral("fatresize")) ? cmdSupportFileSystem : cmdSupportNone;
     m_Shrink = findExternal(QStringLiteral("fatresize")) ? cmdSupportFileSystem : cmdSupportNone;
     m_GetUUID = cmdSupportCore;
+
+    if (m_Create == cmdSupportFileSystem) {
+        addAvailableFeature(QStringLiteral("sector-size"), FSFeature::Type::Int);
+        addAvailableFeature(QStringLiteral("sectors-per-cluster"), FSFeature::Type::Int);
+    }
 }
 
 bool fat16::supportToolFound() const
@@ -84,8 +84,7 @@ qint64 fat16::maxCapacity() const
 
 bool fat16::create(Report& report, const QString& deviceNode)
 {
-    ExternalCommand cmd(report, QStringLiteral("mkfs.fat"), { QStringLiteral("-F16"), QStringLiteral("-I"), QStringLiteral("-v"), deviceNode });
-    return cmd.run(-1) && cmd.exitCode() == 0;
+    return createWithFatSize(report, deviceNode, 16);
 }
 
 bool fat16::resize(Report& report, const QString& deviceNode, qint64 length) const
