@@ -72,6 +72,7 @@ const std::vector<QColor> FileSystem::defaultColorCode =
     QColor( 255,100,100 ), // linux_raid_member
     QColor( 110,20,50 ),   // bitlocker
     QColor( 255,155,174 ), // apfs
+    QColor( 0,170,255 ), // minix
 }
 };
 
@@ -83,6 +84,8 @@ struct FileSystemPrivate {
     qint64 m_SectorsUsed;
     QString m_Label;
     QString m_UUID;
+    QList<FSFeature> m_AvailableFeatures;
+    QList<FSFeature> m_Features;
 };
 
 /** Creates a new FileSystem object
@@ -103,6 +106,26 @@ FileSystem::FileSystem(qint64 firstsector, qint64 lastsector, qint64 sectorsused
     d->m_UUID = QString();
 }
 
+/** Creates a new FileSystem object
+    @param firstsector the first sector used by this FileSystem on the Device
+    @param lastsector the last sector used by this FileSystem on the Device
+    @param sectorsused the number of sectors in use on the FileSystem
+    @param label the FileSystem label
+    @param features the FileSystem features
+    @param type the FileSystem type
+*/
+FileSystem::FileSystem(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features, FileSystem::Type type) :
+    d(std::make_unique<FileSystemPrivate>())
+{
+    d->m_Type = type;
+    d->m_FirstSector = firstsector;
+    d->m_LastSector = lastsector;
+    d->m_SectorsUsed = sectorsused;
+    d->m_Label = label;
+    d->m_Features = features;
+    d->m_UUID = QString();
+}
+
 FileSystem::~FileSystem()
 {
 }
@@ -452,6 +475,7 @@ static const KLocalizedString* typeNames()
         kxi18nc("@item filesystem name", "linux_raid_member"),
         kxi18nc("@item filesystem name", "BitLocker"),
         kxi18nc("@item filesystem name", "apfs"),
+        kxi18nc("@item filesystem name", "minix"),
     };
 
     return s;
@@ -580,6 +604,26 @@ bool FileSystem::findExternal(const QString& cmdName, const QStringList& args, i
     return cmd.exitCode() == 0 || cmd.exitCode() == expectedCode;
 }
 
+void FileSystem::addAvailableFeature(const FSFeature& feature)
+{
+    d->m_AvailableFeatures.append(feature);
+}
+
+void FileSystem::addAvailableFeature(const QString& name, FSFeature::Type type)
+{
+    d->m_AvailableFeatures.append(FSFeature(name, type));
+}
+
+void FileSystem::addFeature(const FSFeature& feature)
+{
+    d->m_Features.append(feature);
+}
+
+void FileSystem::addFeatures(const QList<FSFeature>& features)
+{
+    d->m_Features.append(features);
+}
+
 bool FileSystem::supportToolFound() const
 {
     return false;
@@ -605,6 +649,16 @@ const QString& FileSystem::label() const
     return d->m_Label;
 }
 
+const QList<FSFeature>& FileSystem::availableFeatures() const
+{
+    return d->m_AvailableFeatures;
+}
+
+const QList<FSFeature>& FileSystem::features() const
+{
+    return d->m_Features;
+}
+
 qint64 FileSystem::sectorSize() const
 {
     return d->m_SectorSize;
