@@ -37,7 +37,7 @@ namespace FS
 class LIBKPMCORE_EXPORT hfs : public FileSystem
 {
 public:
-    hfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    hfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
