@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(HFSPLUS__H)
+#if !defined(KPMCORE_HFSPLUS_H)
 
-#define HFSPLUS__H
+#define KPMCORE_HFSPLUS_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -37,7 +37,7 @@ namespace FS
 class LIBKPMCORE_EXPORT hfsplus : public FileSystem
 {
 public:
-    hfsplus(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    hfsplus(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
@@ -71,7 +71,7 @@ public:
     }
 
     qint64 maxCapacity() const override;
-    qint64 maxLabelLength() const override;
+    int maxLabelLength() const override;
     SupportTool supportToolName() const override;
     bool supportToolFound() const override;
 
