@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(LVM2_PV__H)
+#if !defined(KPMCORE_LVM2_PV_H)
 
-#define LVM2_PV__H
+#define KPMCORE_LVM2_PV_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -62,7 +62,22 @@ private:
 };
 
 namespace LVM {
-    extern LIBKPMCORE_EXPORT QList<LvmPV> pvList;
+/** Class to access a global LVM PV list.
+    @author Caio Carvalho <caiojcarvalho@gmail.com>
+*/
+class LIBKPMCORE_EXPORT pvList
+{
+public:
+    static QList<LvmPV> &list() {
+        return m_list;
+    }
+
+private:
+    pvList() { }
+
+private:
+    static QList<LvmPV> m_list;
+};
 }
 
 namespace FS
@@ -74,7 +89,7 @@ class LIBKPMCORE_EXPORT lvm2_pv : public FileSystem
 {
 
 public:
-    lvm2_pv(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    lvm2_pv(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
@@ -155,10 +170,10 @@ public:
     static QList<LvmPV> getPVinNode(const PartitionNode* parent);
     static QList<LvmPV> getPVs(const QList<Device*>& devices);
 
-    qint64 allocatedPE() const { return m_AllocatedPE; };
-    qint64 freePE() const { return m_TotalPE - m_AllocatedPE; };
-    qint64 totalPE() const { return m_TotalPE; };
-    qint64 peSize() const { return m_PESize; };
+    qint64 allocatedPE() const { return m_AllocatedPE; }
+    qint64 freePE() const { return m_TotalPE - m_AllocatedPE; }
+    qint64 totalPE() const { return m_TotalPE; }
+    qint64 peSize() const { return m_PESize; }
 
 private:
     void getPESize(const QString& deviceNode); // return PE size in bytes
