@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(NILFS2__H)
+#if !defined(KPMCORE_NILFS2_H)
 
-#define NILFS2__H
+#define KPMCORE_NILFS2_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -38,16 +38,17 @@ namespace FS
 class LIBKPMCORE_EXPORT nilfs2 : public FileSystem
 {
 public:
-    nilfs2(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    nilfs2(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
 
 //          qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool check(Report& report, const QString& deviceNode) const override;
-    bool create(Report& report, const QString& deviceNode) const override;
+    bool create(Report& report, const QString& deviceNode) override;
     qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
+    bool resizeOnline(Report& report, const QString& deviceNode, const QString& mountPoint, qint64 length) const override;
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
 
@@ -63,9 +64,15 @@ public:
     CommandSupportType supportGrow() const override {
         return m_Grow;
     }
+    CommandSupportType supportGrowOnline() const override {
+        return m_Grow;
+    }
     CommandSupportType supportShrink() const override {
         return m_Shrink;
     }
+    CommandSupportType supportShrinkOnline() const override {
+        return m_Shrink;
+    }
     CommandSupportType supportMove() const override {
         return m_Move;
     }
@@ -90,7 +97,7 @@ public:
 
     qint64 minCapacity() const override;
     qint64 maxCapacity() const override;
-    qint64 maxLabelLength() const override;
+    int maxLabelLength() const override;
     SupportTool supportToolName() const override;
     bool supportToolFound() const override;
 
