@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(REISER4__H)
+#if !defined(KPMCORE_REISER4_H)
 
-#define REISER4__H
+#define KPMCORE_REISER4_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -37,7 +37,7 @@ namespace FS
 class LIBKPMCORE_EXPORT reiser4 : public FileSystem
 {
 public:
-    reiser4(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    reiser4(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
@@ -69,7 +69,7 @@ public:
     }
 
     qint64 maxCapacity() const override;
-    qint64 maxLabelLength() const override;
+    int maxLabelLength() const override;
     SupportTool supportToolName() const override;
     bool supportToolFound() const override;
 
