@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(ZFS__H)
+#if !defined(KPMCORE_ZFS_H)
 
-#define ZFS__H
+#define KPMCORE_ZFS_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -38,7 +38,7 @@ namespace FS
 class LIBKPMCORE_EXPORT zfs : public FileSystem
 {
 public:
-    zfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
+    zfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
 
 public:
     void init() override;
