@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(CREATEFILESYSTEMOPERATION__H)
+#if !defined(KPMCORE_CREATEFILESYSTEMOPERATION_H)
 
-#define CREATEFILESYSTEMOPERATION__H
+#define KPMCORE_CREATEFILESYSTEMOPERATION_H
 
 #include "util/libpartitionmanagerexport.h"
 
