@@ -16,10 +16,11 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#include "ops/operation.h"
+#include "ops/operation_p.h"
 
 #include "core/partition.h"
 #include "core/device.h"
+#include "core/lvmdevice.h"
 
 #include "jobs/job.h"
 
@@ -32,10 +33,10 @@
 #include <KLocalizedString>
 
 Operation::Operation() :
-    m_Status(StatusNone),
-    m_Jobs(),
-    m_ProgressBase(0)
+    d(std::make_unique<OperationPrivate>())
 {
+    d->m_Status = StatusNone;
+    d->m_ProgressBase = 0;
 }
 
 Operation::~Operation()
@@ -50,7 +51,14 @@ void Operation::insertPreviewPartition(Device& device, Partition& p)
 
     device.partitionTable()->removeUnallocated();
 
-    p.parent()->insert(&p);
+    if (p.parent()->insert(&p)) {
+        if (device.type() == Device::Type::LVM_Device) {
+            const LvmDevice& lvm = static_cast<const LvmDevice&>(device);
+            lvm.setFreePE(lvm.freePE() - p.length());
+        }
+    }
+    else
+        qWarning() << "failed to insert preview partition " << p.deviceNode() << " at " << &p << ".";
 
     device.partitionTable()->updateUnallocated(device);
 }
@@ -59,8 +67,14 @@ void Operation::removePreviewPartition(Device& device, Partition& p)
 {
     Q_ASSERT(device.partitionTable());
 
-    if (p.parent()->remove(&p))
+    if (p.parent()->remove(&p)) {
+        if (device.type() == Device::Type::LVM_Device) {
+            const LvmDevice& lvm = static_cast<const LvmDevice&>(device);
+            lvm.setFreePE(lvm.freePE() + p.length());
+        }
+
         device.partitionTable()->updateUnallocated(device);
+    }
     else
         qWarning() << "failed to remove partition " << p.deviceNode() << " at " << &p << " from preview.";
 }
@@ -172,3 +186,33 @@ bool Operation::execute(Report& parent)
 
     return rval;
 }
+
+Operation::OperationStatus Operation::status() const
+{
+    return d->m_Status;
+}
+
+void Operation::setStatus(OperationStatus s)
+{
+    d->m_Status = s;
+}
+
+QList<Job*>& Operation::jobs()
+{
+    return d->m_Jobs;
+}
+
+const QList<Job*>& Operation::jobs() const
+{
+    return d->m_Jobs;
+}
+
+void Operation::setProgressBase(qint32 i)
+{
+    d->m_ProgressBase = i;
+}
+
+qint32 Operation::progressBase() const
+{
+    return d->m_ProgressBase;
+}
