@@ -33,7 +33,7 @@ class DummyDevice : public CoreBackendDevice
     Q_DISABLE_COPY(DummyDevice)
 
 public:
-    DummyDevice(const QString& device_node);
+    DummyDevice(const QString& deviceNode);
     ~DummyDevice();
 
 public:
@@ -41,12 +41,9 @@ public:
     bool openExclusive() override;
     bool close() override;
 
-    CoreBackendPartitionTable* openPartitionTable() override;
+    std::unique_ptr<CoreBackendPartitionTable> openPartitionTable() override;
 
     bool createPartitionTable(Report& report, const PartitionTable& ptable) override;
-
-    bool readData(QByteArray& buffer, qint64 offset, qint64 size) override;
-    bool writeData(QByteArray& buffer, qint64 offset) override;
 };
 
 #endif
