@@ -25,6 +25,7 @@ QStringLiteral("udevadm"),
 
 //Core programs
 QStringLiteral("blockdev"),
+QStringLiteral("partx"),
 QStringLiteral("sfdisk"),
 QStringLiteral("wipefs"),
 QStringLiteral("lvm"),
@@ -69,6 +70,8 @@ QStringLiteral("swapon"),
 QStringLiteral("swapoff"),
 QStringLiteral("cryptsetup"),
 QStringLiteral("dmsetup"),
+QStringLiteral("fsck.minix"),
+QStringLiteral("mkfs.minix"),
 QStringLiteral("fsck.nilfs2"),
 QStringLiteral("mkfs.nilfs2"),
 QStringLiteral("nilfs-tune"),
