@@ -28,13 +28,10 @@
 int main( int argc, char** argv )
 {
     QCoreApplication app(argc, argv);
-    if ( argc != 2 )
-    {
+    if ( argc != 2 ) {
         KPMCoreInitializer i;
         return i.isValid() ? 0 : 1;
-    }
-    else
-    {
+    } else {
         KPMCoreInitializer i( argv[1] );
         return i.isValid() ? 0 : 1;
     }
